/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: SpecificWarFieldMetadata.java 3600 2008-07-04 15:25:28Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.war.impl.specific;

import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.war.api.IWarClassMetadata;
import org.ow2.util.ee.metadata.war.api.IWarFieldMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificClassMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.specific.ISpecificMethodMetadata;
import org.ow2.util.scan.api.metadata.specific.SpecificFieldMetadata;
import org.ow2.util.scan.api.metadata.structures.JField;

/**
 * SpecificWarFieldMetadata.
 * @param <SC> specific class metadata
 * @param <SM> specific method metadata
 * @param <SF> specific field metadata
 * @author Gael Lalire
 */
public class SpecificWarFieldMetadata<
    SC extends ISpecificClassMetadata<SC, SM, SF>,
    SM extends ISpecificMethodMetadata<SC, SM, SF>,
    SF extends ISpecificFieldMetadata<SC, SM, SF>>
        extends SpecificFieldMetadata<SC, SM, SF> implements IWarFieldMetadata {

    /**
     * The standard war method metadata.
     */
    private IWarFieldMetadata warFieldMetadata;

    public SpecificWarFieldMetadata(final IWarFieldMetadata warFieldMetadata, final SC classMetadata) {
        super(classMetadata);
        this.warFieldMetadata = warFieldMetadata;
    }

    public JField getJField() {
        return warFieldMetadata.getJField();
    }

    /**
     * {@inheritDoc}
     */
    public IJEjbEJB getJEjbEJB() {
        return warFieldMetadata.getJEjbEJB();
    }

    /**
     * {@inheritDoc}
     */
    public void setJEjbEJB(final IJEjbEJB ejbEJB) {
        warFieldMetadata.setJEjbEJB(ejbEJB);
    }

    /**
     * {@inheritDoc}
     */
    public IJAnnotationResource getJAnnotationResource() {
        return warFieldMetadata.getJAnnotationResource();
    }

    /**
     * {@inheritDoc}
     */
    public void setJAnnotationResource(final IJAnnotationResource annotationResource) {
        warFieldMetadata.setJAnnotationResource(annotationResource);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceContext getJavaxPersistenceContext() {
        return warFieldMetadata.getJavaxPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceContext() {
        return warFieldMetadata.isPersistenceContext();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        warFieldMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * {@inheritDoc}
     */
    public IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return warFieldMetadata.getJavaxPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public boolean isPersistenceUnit() {
        return warFieldMetadata.isPersistenceUnit();
    }

    /**
     * {@inheritDoc}
     */
    public void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        warFieldMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * {@inheritDoc}
     */
    public IWarFieldMetadata attachClone(final IWarClassMetadata classMetadata) throws CloneNotSupportedException {
        return warFieldMetadata.attachClone(classMetadata);
    }

    /**
     * {@inheritDoc}
     */
    public IWarClassMetadata getClassMetadata() {
        return warFieldMetadata.getClassMetadata();
    }

}
